{% load crispy_forms_utils %}

{% specialspaceless %}
    {% if form_tag %}<form {{ flat_attrs }} method="{{ form_method }}" {% if form.is_multipart %} enctype="multipart/form-data"{% endif %}>{% endif %}
    {% if form_method|lower == 'post' and not disable_csrf %}
        {% csrf_token %}
    {% endif %}

    {% include "unfold_crispy/display_form.html" %}

    {% include "unfold_crispy/inputs.html" %}

    {% if form_tag %}</form>{% endif %}
{% endspecialspaceless %}
