{% load admin_urls i18n %}

{% if has_export_permission %}
    {% trans "Export" as title %}
    {% url opts|admin_urlname:'export' as link %}
    {% include "unfold/helpers/tab_action.html" with title=title link=link|add:cl.get_query_string %}
{% endif %}
