{% load admin_list unfold %}

{% if cl %}
    <div {% if not is_popup %}class="px-4 lg:backdrop-blur-xs lg:bg-white/80 lg:flex lg:items-center lg:dark:bg-base-900/80 lg:left-0 lg:right-0 lg:bottom-0 lg:sticky relative z-40 {% if not is_popup %}lg:border-t lg:border-base-200 lg:relative lg:scrollable-top lg:dark:border-base-800{% endif %} {% element_classes 'pagination' %}"{% endif %}>
        {% pagination cl %}
    </div>
{% endif %}
